#=========================================================================#
#                                 CWT-LD                                  #
#=========================================================================#

# Leaf Decomposition Reciprocal Transplant Experiment

# Author: David Stoker (dstoker92@gmail.com)
# Last Updated: 17 May 2017

## Table of Contents
# Line  22: Loading Packages and Data
# Line  48: Site Survey
# Line 146: Leaf Decomposition and Stoichiometry
# Line 248: Functional Trait Diversity
# Line 279: Detritivore Community Analyses
# Line 448: Structural Equation Modeling
# Line 625: Figures
# Line 920: End of script

#=========================================================================#
#                          Load Packages and Data                         #
#==========================================================================
library(AICcmodavg)
library(FD)
library(lavaan)
library(nlme)
library(plyr)
library(reshape2)
library(vegan)


setwd("~/Documents/Research/CWT-LD/CSV Files")

## Read in data
survey     <- read.csv("CWT-site_survey.csv")
traits     <- read.csv("CWT-traits.csv", row.names = "taxa")
model.data <- read.csv("CWT-model_data.csv")

## Abundance dataframe
taxa       <- c("amph", "chir", "lepi", "lept", "leuc", "paral", 
                "pycn", "tall")
abundances <- model.data[, paste(taxa, ".abund", sep = "")]
colnames(abundances) = rownames(traits)


#=========================================================================#
#                                Site Survey                              #
#==========================================================================

## Normality Tests & Transformations---------------------------------------

## Shapiro-Wilks test of normality for environmental variables
shapiro.test(survey$width) # not normal
shapiro.test(survey$depth) # normal
shapiro.test(survey$cover) # not normal
shapiro.test(survey$flow)  # normal (transform to improve normality)
shapiro.test(survey$temp)  # not normal

## Data transformations
width.t <- log(survey$width)
flow.t  <- log(survey$flow)
temp.t  <- log(survey$temp)

## Shapiro-Wilks test of normality for transformed variables
shapiro.test(survey$width.t) # normal
shapiro.test(survey$flow.t)  # normal
shapiro.test(survey$temp.t)  # not normal, but improved

# Most transformations were satisfactory
# Mean daily water temperature still not normal, but improved
# cover not transformed, requires non-standard transformation (cover^4)


## Site Survey ANOVAs------------------------------------------------------

## Univariate ANOVA for each environmental characteristic.

# To adjust for mutiple comparisons, Bonferroni correction will be used
# Standard alpha = 0.05
# For multiple comparisons (5), alpha = 0.01 will be used
# 0.01 = (0.05/5)

## Wetted-width
width.aov <- lm(width.t ~ as.factor(stream), na.action = na.exclude, data = survey)
anova(width.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(width.aov)
par(mfrow = c(1, 1))
hist(resid(width.aov))
plot(residuals(width.aov))
abline(h = 0, lty = 2)

## Depth
depth.aov <- lm(depth ~ as.factor(stream), na.action = na.exclude, data = survey)
anova(depth.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(depth.aov)
par(mfrow = c(1, 1))
hist(resid(depth.aov))
plot(residuals(depth.aov))
abline(h = 0, lty = 2)

## Canopy cover
cover.aov <- lm(cover ~ as.factor(stream), na.action = na.exclude, data = survey)
anova(cover.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(cover.aov)
par(mfrow = c(1, 1))
hist(resid(cover.aov))
plot(residuals(cover.aov))
abline(h = 0, lty = 2)

## Flow velocity
flow.aov <- lm(flow.t ~ as.factor(stream), na.action = na.exclude, data = survey)
anova(flow.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(flow.aov)
par(mfrow = c(1, 1))
hist(resid(flow.aov))
plot(residuals(flow.aov))
abline(h = 0, lty = 2)

## Water temperature
temp.aov <- lm(temp.t ~ as.factor(stream), na.action = na.exclude, data = survey)
anova(temp.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(temp.aov)
par(mfrow = c(1, 1))
hist(resid(temp.aov))
plot(residuals(temp.aov))
abline(h = 0, lty = 2)


#=========================================================================#
#                   Leaf Decomposition and Stoichiometry                  #
#==========================================================================

## Transform decomp
model.data$decomp.2 <- log(model.data$decomp)

## Shapiro-Wilks test of ln-transformed decomp variable
shapiro.test(model.data$decomp.2)

## Exploratory plots
par(mfrow = c(1, 1))
hist(model.data$decomp.2, main = "Histogram of % Mass Lost")
boxplot(decomp.2 ~ as.factor(stream), ylab = "% Mass Lost", xlab = "Stream", 
        col = "gray0", data = model.data)
boxplot(decomp.2 ~ pack, ylab = "% Mass Lost", 
        xlab = "Leaf Pack Type", col = "gray0", data = model.data)
boxplot(decomp.2 ~ deployment, ylab = "% Mass Lost", 
        xlab = "Deployment Site", col = "gray0", data = model.data)
boxplot(decomp.2 ~ deployment + pack, ylab = "% Mass Lost",
        col = "gray0", data = model.data)

## Leaf Decomposition ANOVA-----------------------------------------------#

## Compare leaf decomposition by pack type and deployment site
decomp.aov <- lme(decomp.2 ~ pack + deployment,
                  random = ~ 1|as.factor(stream),
                  data = model.data)
summary(decomp.aov)
anova(decomp.aov)

## Check leaf decomposition ANOVA model assumptions
par(mfrow = c(1, 1))
plot(decomp.aov)
hist(resid(decomp.aov))
plot(residuals(decomp.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(decomp.aov)))


## Summarize leaf decomposition data
ld.pack.summary <- ddply(model.data, c("pack"), summarise,
                         N    = sum(!is.na(decomp)),
                         mean = mean(decomp, na.rm = TRUE),
                         sd   = sd(decomp, na.rm = TRUE),
                         se   = sd / sqrt(N)
)
ld.pack.summary

ld.deployment.summary <- ddply(model.data, c("deployment"), summarise,
                               N    = sum(!is.na(decomp)),
                               mean = mean(decomp, na.rm = TRUE),
                               sd   = sd(decomp, na.rm = TRUE),
                               se   = sd / sqrt(N)
)
ld.deployment.summary

ld.summary <- ddply(model.data, c("pack", "deployment"), summarise,
                    N    = sum(!is.na(decomp)),
                    mean = mean(decomp, na.rm = TRUE),
                    sd   = sd(decomp, na.rm = TRUE),
                    se   = sd / sqrt(N)
)
ld.summary

## Leaf Pack Stoichiometry------------------------------------------------#

## t-tests to compare C:N and C:P between pack types

## C:N
t.test(model.data[model.data$pack == "LEP", 6], 
			 model.data[model.data$pack == "HEP", 6], 
			 alternative = "two.sided", conf.level = 0.95)
# t = 7.1695, DF = 59.995, P = 1.286e-09

# HEPs had signicantly lower C:N (i.e. higher N content)

## C:P
t.test(model.data[model.data$pack == "LEP", 7], 
			 model.data[model.data$pack == "HEP", 7], 
			 alternative = "two.sided", conf.level = 0.95)
# t = 3.0769, DF = 59.938, P = 0.00315

# HEPs had signicantly lower C:P (i.e. higher P content)

CN.summary <- ddply(model.data, c("pack"), summarise,
										N    = sum(!is.na(CN)),
										mean = mean(CN, na.rm = TRUE),
										sd   = sd(CN, na.rm = TRUE),
										se   = sd / sqrt(N)
)
CN.summary

CP.summary <- ddply(model.data, c("pack"), summarise,
										N    = sum(!is.na(CP)),
										mean = mean(CP, na.rm = TRUE),
										sd   = sd(CP, na.rm = TRUE),
										se   = sd / sqrt(N)
)
CP.summary


#=========================================================================#
#                         Functional Trait Diversity                      #
#==========================================================================

## Calculating two functional trait diversity metrics: FRic and FDis

## Functional Richness (FRic)
FRic <- do.call(data.frame, dbFD(traits, abundances, stand.FRic = TRUE,
                calc.CWM = FALSE, messages = FALSE))[,"FRic", drop = FALSE]

colnames(FRic) <- paste(colnames(FRic), sep = "")

FRic <- cbind.data.frame(id = model.data[match(rownames(FRic),
                         rownames(model.data)), "id"], FRic)

model.data <- join_all(list(model.data, FRic), by = "id")


## Functional Dispersion (FDis)
FDis <- do.call(data.frame, dbFD(traits, abundances, stand.FRic = TRUE,
                calc.CWM = FALSE, messages = FALSE))[,"FDis", drop = FALSE]

colnames(FDis) = paste(colnames(FDis), sep = "")

FDis = cbind.data.frame(id = model.data[match(rownames(FDis),
                        rownames(model.data)), "id"], FDis)

## Bind into model.data
model.data <- join_all(list(model.data, FDis), by = "id")


#=========================================================================#
#                      Detritivore Community Analyses                     #
#=========================================================================#

#-------------------------------------------------------------------------#
#                           Community Composition                         #
#--------------------------------------------------------------------------

## Bray-Curtis dissimilarity and PERMANOVA

## Calculate Bray-Curtis dissimilarity and set basic NMDS plot
BC.dis  <- vegdist(abundances, method = "bray")
BC.NMDS <- monoMDS(BC.dis, k = 2, model = "global")
BC.NMDS

plot(BC.NMDS)

## Shepard plot
stressplot(BC.NMDS)

## PERMANOVA
adonis(BC.dis ~ pack + as.factor(stream), data = model.data, permutations = 10000)

#-------------------------------------------------------------------------#
#                  Functional Trait Diversity Comparisons                 #
#--------------------------------------------------------------------------

## Compare FRic and FDis by pack type and stream

## FRic ANOVA
FRic.aov <- aov(FRic ~ pack + as.factor(stream), data = model.data)
summary(FRic.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(FRic.aov)
par(mfrow = c(1, 1))
hist(resid(FRic.aov))
plot(residuals(FRic.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(FRic.aov)))

## FDis ANOVA
FDis.aov <- aov(FDis ~ pack + as.factor(stream), data = model.data)
summary(FDis.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(FDis.aov)
par(mfrow = c(1, 1))
hist(resid(FDis.aov))
plot(residuals(FDis.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(FDis.aov)))

# Both FRic.mod and FDis.mod heteroskedasticity and normality of errors
# assessed visually


## Summarize detritivore functional trait diversity data

## FRic
FRic.pack.summary <- ddply(model.data, c("pack"), summarise,
                   N    = sum(!is.na(FRic)),
                   mean = mean(FRic, na.rm = TRUE),
                   sd   = sd(FRic, na.rm = TRUE),
                   se   = sd / sqrt(N)
)
FRic.pack.summary

FRic.stream.summary <- ddply(model.data, c("stream"), summarise,
                      N    = sum(!is.na(FRic)),
                      mean = mean(FRic, na.rm = TRUE),
                      sd   = sd(FRic, na.rm = TRUE),
                      se   = sd / sqrt(N)
)
FRic.stream.summary

## FDis
FDis.pack.summary <- ddply(model.data, c("pack"), summarise,
                     N    = sum(!is.na(FDis)),
                     mean = mean(FDis, na.rm = TRUE),
                     sd   = sd(FDis, na.rm = TRUE),
                     se   = sd / sqrt(N)
)
FDis.pack.summary

FDis.stream.summary <- ddply(model.data, c("stream"), summarise,
                      N    = sum(!is.na(FDis)),
                      mean = mean(FDis, na.rm = TRUE),
                      sd   = sd(FDis, na.rm = TRUE),
                      se   = sd / sqrt(N)
)
FDis.stream.summary


#-------------------------------------------------------------------------#
#                       Biomass and Density Comparisons                   #
#--------------------------------------------------------------------------

## Compare biomass and density by pack type and stream

## Biomass ANOVA
biomass.aov <- aov(biomass ~ pack + as.factor(stream), data = model.data)
summary(biomass.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(biomass.aov)
par(mfrow = c(1, 1))
hist(resid(biomass.aov))
plot(residuals(biomass.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(biomass.aov)))

## Density ANOVA
density.aov <- aov(density ~ pack + as.factor(stream), data = model.data)
summary(density.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(density.aov)
par(mfrow = c(1, 1))
hist(resid(density.aov))
plot(residuals(density.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(density.aov)))

# Both biomass.mod and density.mod heteroskedasticity and normality of errors
# assessed visually


## Summarize detritivore biomass and density data

## biomass
biomass.pack.summary <- ddply(model.data, c("pack"), summarise,
													    N    = sum(!is.na(biomass)),
													    mean = mean(biomass, na.rm = TRUE),
													    sd   = sd(biomass, na.rm = TRUE),
													    se   = sd / sqrt(N)
)
biomass.pack.summary

biomass.stream.summary <- ddply(model.data, c("stream"), summarise,
														    N    = sum(!is.na(biomass)),
														    mean = mean(biomass, na.rm = TRUE),
														    sd   = sd(biomass, na.rm = TRUE),
														    se   = sd / sqrt(N)
)
biomass.stream.summary

## density
density.pack.summary <- ddply(model.data, c("pack"), summarise,
													    N    = sum(!is.na(density)),
													    mean = mean(density, na.rm = TRUE),
													    sd   = sd(density, na.rm = TRUE),
													    se   = sd / sqrt(N)
)
density.pack.summary

density.stream.summary <- ddply(model.data, c("stream"), summarise,
														    N    = sum(!is.na(density)),
														    mean = mean(density, na.rm = TRUE),
														    sd   = sd(density, na.rm = TRUE),
														    se   = sd / sqrt(N)
)
density.stream.summary


#=========================================================================#
#                        Structural Equation Modeling                     #
#=========================================================================#

## Adjust variables
model.data$FRic.2 <- model.data$FRic * 10
model.data$FDis.2 <- model.data$FDis * 5
model.data$CP.2   <- model.data$CP/100

#-------------------------------------------------------------------------#
#                                   SEMs                                  #
#--------------------------------------------------------------------------


## FD and C:N-------------------------------------------------------------#
## FRic/C:N
## P = 0.341, so model is valid
SEM1 <- "CN ~ stream + pack
         biomass ~ stream + pack
         density ~ stream + pack + CN
         FRic.2  ~ stream
         decomp  ~ stream + pack + biomass + density + FRic.2 + CN
         biomass ~~ density
         FRic.2  ~~ density
         FRic.2  ~~ biomass"

SEM1fit <- sem(SEM1, data = model.data, fixed.x = FALSE, estimator = "MLM")
SEM1fit
summary(SEM1fit, rsq = TRUE, standardized = TRUE, modindices = TRUE)
# Added FRic.2 ~~ biomass to improve model fit based on single DF 
# chi-square criteria
standardizedSolution(SEM1fit, type = "std.all") # Get path coefficients

## FDis/C:N
## P = 0.593, so model is valid
SEM2 <- "CN ~ stream + pack
         biomass ~ stream + pack
         density ~ stream + pack + CN
         FDis.2  ~ stream + CN
         decomp  ~ stream + pack + biomass + density + FDis.2 + CN
         biomass ~~ density
         FDis.2  ~~ density
         FDis.2  ~~ biomass"

SEM2fit <- sem(SEM2, data = model.data, fixed.x = FALSE, estimator = "MLM")
SEM2fit
summary(SEM2fit, rsq = TRUE, standardized = TRUE, modindices = TRUE)
# Added FDis.2 ~~ biomass and FDis.2 ~ CN to improve model fit based on
# single DF chi-square criteria
standardizedSolution(SEM2fit, type = "std.all") # Get path coefficients


## FD and C:P-------------------------------------------------------------#
## FRic/C:P
## P = 0.581, so model is valid
SEM3 <- "CP.2 ~ stream + pack
         biomass ~ stream + pack
         density ~ stream + pack + CP.2
         FRic.2  ~ stream
         decomp  ~ stream + pack + biomass + density + FRic.2 + CP.2
         biomass ~~ density
         FRic.2  ~~ density
         FRic.2  ~~ biomass"

SEM3fit <- sem(SEM3, data = model.data, fixed.x = FALSE, estimator = "MLM")
SEM3fit
summary(SEM3fit, rsq = TRUE, standardized = TRUE, modindices = TRUE)
# Added  FRic.2 ~~ biomass to improve model fit based on
# single DF chi-square criteria.
standardizedSolution(SEM3fit, type = "std.all") # Get path coefficients

## FDis/C:P
## P = 0.849, so model is valid
SEM4 <- "CP.2 ~ stream + pack
         biomass ~ stream + pack
         density ~ stream + pack + CP.2
         FDis.2  ~ stream + CP.2
         decomp  ~ stream + pack + biomass + density + FDis.2 + CP.2
         biomass ~~ density
         FDis.2  ~~ density
         FDis.2  ~~ biomass"

SEM4fit <- sem(SEM4, data = model.data, fixed.x = FALSE, estimator = "MLM")
SEM4fit
summary(SEM4fit, rsq = TRUE, standardized = TRUE, modindices = TRUE)
# Added FDis.2 ~~ biomass and FDis.2 ~ CP to improve model fit based on
# single DF chi-square criteria.
standardizedSolution(SEM4fit, type = "std.all") # Get path coefficients


#-------------------------------------------------------------------------#
#                                 SEM AICc                                #
#--------------------------------------------------------------------------

# Select most parsimonious and best-fitting SEM out of the four 
# candidate models.

## Define function
AICc.lavaan <- function(object, second.ord = TRUE, c.hat = 1, return.K = FALSE){
  object <- as.list(fitMeasures(object))
  npar <- object$baseline.df - object$df
  if(return.K == T) return(object$npar)
  if(second.ord == F && c.hat > 1) return(-2 * object$logl / c.hat + 2 * npar)
  if(second.ord == F ) return(object$aic)
  if(c.hat > 1) return(-2 * object$logl / c.hat + 2 * npar + 
                         2 * (npar * (object$npar + 1)) / (object$ntotal - npar-1))
  object$aic + 2 * (npar * (npar + 1)) / (object$ntotal - npar - 1)
}

aictab.lavaan <- function(cand.set, modnames, sort = TRUE, c.hat = 1, 
                          second.ord = TRUE, nobs = NULL){
  if(is.null(modnames)) modnames <- 1:length(cand.set)
  # check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
  # if (length(unique(check.resp)) > 1) 
  #     stop("You must use the same response variable for all models\n")
  Results <- NULL
  Results <- data.frame(Modnames = modnames)
  Results$K <- unlist(lapply(X = cand.set, FUN = AICc.lavaan, 
                             return.K = TRUE, c.hat = c.hat, 
                             second.ord = second.ord))
  Results$AICc <- unlist(lapply(X = cand.set, FUN = AICc.lavaan, 
                                return.K = FALSE, c.hat = c.hat,
                                second.ord = second.ord))
  Results$Delta_AICc <- Results$AICc - min(Results$AICc)
  Results$ModelLik <- exp(-0.5 * Results$Delta_AICc)
  Results$AICcWt <- Results$ModelLik / sum(Results$ModelLik)
  if (length(unique(Results$AICc)) != length(cand.set)) 
    warning("\nCheck model structure carefully as some models may be redundant\n")
  if (second.ord == TRUE && c.hat == 1) {
    Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
  }
  if (second.ord == TRUE && c.hat > 1) {
    colnames(Results) <- c("Modnames", "K", "QAICc", "Delta QAICc", 
                           "ModelLik", "QAICcWt")
    LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
    Results$Quasi.LL <- LL/c.hat
    Results$c_hat <- c.hat
  }
  if (second.ord == FALSE && c.hat == 1) {
    colnames(Results) <- c("Modnames", "K", "AIC", "Delta AIC", 
                           "ModelLik", "AICWt")
    Results$LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
  }
  if (second.ord == FALSE && c.hat > 1) {
    colnames(Results) <- c("Modnames", "K", "QAIC", "Delta QAIC", 
                           "ModelLik", "QAICWt")
    LL <- unlist(lapply(X = cand.set, FUN = function(i) logLik(i)[1]))
    Results$Quasi.LL <- LL/c.hat
    Results$c_hat <- c.hat
  }
  if (sort) {
    Results <- Results[rev(order(Results[, 6])), ]
    Results$Cum.Wt <- cumsum(Results[, 6])
  }
  else {
    Results$Cum.Wt <- NULL
  }
  class(Results) <- c("aictab", "data.frame")
  return(Results)
}

## Note: Code for the above function provided by Jarrett E. K. Byrnes.
## I do not claim authroship of the code for the function.
## All credit is reserved for Jarret E. K. Byrnes.


## SEM ranking
aictab.lavaan(list(SEM1fit, SEM2fit, SEM3fit, SEM4fit),
              c("FRic/C:N","FDis/C:N", "FRic/C:P", "FDis/C:P"))

# Model ranking
# 1. FRic/C:P
# 2. FRic/C:N
# 3. FDis/C:P
# 4. FDis/C:N


#=========================================================================#
#                                  Figures                                #
#=========================================================================#

#-------------------------------------------------------------------------#
#                         Leaf Decomposition Figure                       #
#--------------------------------------------------------------------------

ld.range <- c(0, 35)

## Set mean and standard error values
## Pack type (p)
ld.p.means <- c(19.65037, 27.51466)
ld.p.SEs   <- c(1.033981, 1.610544)

## Deployment (d)
ld.d.means <- c(24.60330, 22.87128)
ld.d.SEs   <- c(1.490731, 1.581468)

## Set figure parameters
par(mfrow = c(1, 2))
par(mai = c(0.8, 0.8, 0.1, 0.05), omi = c(0.05, 0.05, 0.05, 0.05))

## Plot decomposition by pack type
plot(c(0.1, 0.2), ld.p.means, pch = 19, type = "p", ylim = c(0, 35),
     xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 3, col = "gray0", 
     cex = 1.85)
axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), 
     cex.axis = 1.6)
axis(2, las = 1, at = 5 * 0:ld.range[2], cex.axis = 1.65)
title(xlab = "Leaf Pack Type", ylab = "Leaf Decomposition (% Mass Lost)", 
      cex.lab = 1.65, line = 2.75)
arrows(axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), cex.axis = 1.6),
       ld.p.means - ld.p.SEs,
       axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), cex.axis = 1.6),
       ld.p.means + ld.p.SEs,
       length = 0.05, angle = 90, code = 3, lwd = 3, col = "gray0")
mtext(text = expression(bold("A")), side = 3, line = -1.75, adj = 0.05, 
      cex = 1.65)
box(lwd = 2)

## Plot decomposition by deployment
plot(c(0.1, 0.2), ld.d.means, pch = 19, type = "p", ylim = c(0, 35),
     xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 3, col = "gray0",
     cex = 1.85)
axis(1, at = c(0.1, 0.2), lab = c("Home", "Away"), 
     cex.axis = 1.6)
title(xlab = "Deployment", cex.lab = 1.65, line = 2.75)
arrows(axis(1, at = c(0.1, 0.2), lab = c("Home", "Away"), cex.axis = 1.6),
       ld.d.means - ld.d.SEs,
       axis(1, at = c(0.1, 0.2), lab = c("Home", "Away"), cex.axis = 1.6),
       ld.d.means + ld.d.SEs,
       length = 0.05, angle = 90, code = 3, lwd = 3, col = "gray0")
mtext(text = expression(bold("B")), side = 3, line = -1.75, adj = 0.05, 
      cex = 1.65)
box(lwd = 2)


#-------------------------------------------------------------------------#
#                        Community Composition Figure                     #
#--------------------------------------------------------------------------

## Define streams
streams <- c(rep("LE1", 14), rep("LE2", 16), rep("HE1", 16), rep("HE2", 16))
# Define leaf pack communities
packs <- c(rep("LEP", 6), rep("HEP", 8), rep("LEP", 8), rep("HEP", 8),
           rep("LEP", 8), rep("HEP", 8), rep("LEP", 8), rep("HEP", 8))

## Set figure parameters
par(mfrow = c(2, 1))
par(mai = c(0.95, 0.95, 0.1, 0.1), omi = c(0.025, 0.025, 0.025, 0.025))
#par(xpd = true)

## NMDS of Bray-Curtis dissimilarities (pack type)
plot(BC.NMDS, choices = c(1, 2), type = "none", xlim = c(-2.0, 2.0), 
     las = 1, ylim = c(-1, 1), xlab = "NMDS Axis 1", ylab = "NMDS Axis 2",
     mgp = c(3.25, 1, 0), cex.lab = 1.35, cex.axis = 1.25)
mtext(text = "Stress = 0.16", side = 3, line = -1.5, adj = 0.95, 
      cex = 1.05)
mtext(text = expression(bold("A")), side = 3, line = -1.75, adj = 0.025, 
      cex = 1.25)
with(abundances, ordiellipse(BC.NMDS, packs, draw = "lines",
                             col = "gray0", show.groups = "LEP", 
                             label = FALSE, lty = 1, lwd = 2))
with(abundances, ordiellipse(BC.NMDS, packs, draw = "lines",
                             col = "gray65", show.groups = "HEP", 
                             label = FALSE, lty = 1, lwd = 2))


## NMDS of Bray-Curtis dissimilarities (stream)
plot(BC.NMDS, choices = c(1, 2), type = "none", xlim = c(-2.0, 2.0), 
     las = 1, ylim = c(-1, 1), xlab = "NMDS Axis 1", ylab = "NMDS Axis 2",
     mgp = c(3.25, 1, 0), cex.lab = 1.35, cex.axis = 1.25)
mtext(text = "Stress = 0.16", side = 3, line = -1.5, adj = 0.95, 
      cex = 1.05)
mtext(text = expression(bold("B")), side = 3, line = -1.75, adj = 0.025, 
      cex = 1.25)
with(abundances, ordiellipse(BC.NMDS, streams, draw = "lines",
                             col = "gray0", show.groups = "LE1", 
                             label = FALSE, lty = 1, lwd = 2))
with(abundances, ordiellipse(BC.NMDS, streams, draw = "lines",
                             col = "gray0", show.groups = "LE2", 
                             label = FALSE, lty = 2, lwd = 2))
with(abundances, ordiellipse(BC.NMDS, streams, draw = "lines",
                             col = "gray65", show.groups = "HE1", 
                             label = FALSE, lty = 1, lwd = 2))
with(abundances, ordiellipse(BC.NMDS, streams, draw = "lines",
                             col = "gray65", show.groups = "HE2", 
                             label = FALSE, lty = 2, lwd = 2))


#-------------------------------------------------------------------------#
#                         Detritivore Community Figure                    #
#--------------------------------------------------------------------------

## Set mean and standard error values
## FRic by pack type (FRic.p)
FRic.p.means <- c(0.4919075, 0.5820488)
FRic.p.SEs   <- c(0.04277856, 0.04851795)

## FRic by stream (FRic.s)
FRic.s.means <- c(0.5064640, 0.6975100, 0.5748146, 0.3709436)
FRic.s.SEs   <- c(0.05702998, 0.05818189, 0.03734610, 0.07704851)

## FDis by pack type (FDis.p)
FDis.p.means <- c(2.065627, 2.334412)
FDis.p.SEs   <- c(0.1253050, 0.1493401)

## FRic by stream (FDis.s)
FDis.s.means <- c(2.053314, 1.769147, 2.714000, 2.262078)
FDis.s.SEs   <- c(0.1791494, 0.1121793, 0.1480060, 0.2451167)

## Biomass by pack type (biomass.p)
biomass.p.means <- c(4.32, 7.54)
biomass.p.SEs   <- c(0.50, 0.97)

## Biomass by stream (biomass.s)
biomass.s.means <- c(5.75, 4.55, 8.66, 4.95)
biomass.s.SEs   <- c(1.22, 0.66, 1.38, 1.14)

## Density by pack type (density.p)
density.p.means <- c(23.53, 31.03)
density.p.SEs   <- c(1.75, 2.88)

## Density by stream (density.s)
density.s.means <- c(28.74, 23.25, 36.67, 21.10)
density.s.SEs   <- c(3.73, 2.94, 3.83, 2.33)

## Set figure parameters
par(mfrow = c(4, 2))
par(mai = c(0.5, 0.75, 0.1, 0.1), omi = c(0.05, 0.05, 0.05, 0.05))

## Plot FRic--------------------------------------------------------------#

## By pack type
plot(c(0.1, 0.2), FRic.p.means, pch = 19, type = "p", ylim = c(0, 1), 
     xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
     cex = 1.25)
axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5)
axis(2, las = 1, at = c(0, 0.5, 1), cex.axis = 1.45)
title(ylab = "FRic", cex.lab = 1.65, line = 3.75)
mtext(text = expression(bold("A")), side = 3, line = -1.75, adj = 0.05, 
      cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
       FRic.p.means - FRic.p.SEs,
       axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
       FRic.p.means + FRic.p.SEs,
       length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## By stream
plot(c(0.1, 0.2, 0.3, 0.4), FRic.s.means, pch = 19, type = "p", ylim = c(0, 1),
     xlim = c(0, 0.5), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
     cex = 1.25)
axis(1, at = c(0.1, 0.2, 0.3, 0.4), lab = FALSE, tick = FALSE, 
     cex.axis = 1.55)
mtext(text = expression(bold("B")), side = 3, line = -1.75, adj = 0.05, 
      cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
            lab = FALSE, tick = FALSE, cex.axis = 1.5),
       FRic.s.means - FRic.s.SEs,
       axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
            lab = FALSE, tick = FALSE, cex.axis = 1.5),
       FRic.s.means + FRic.s.SEs,
       length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## Plot FDis--------------------------------------------------------------#

## By pack type
plot(c(0.1, 0.2), FDis.p.means, pch = 19, type = "p", ylim = c(0, 3), 
		 xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5)
axis(2, las = 1, at = c(0, 1, 2, 3), cex.axis = 1.45)
title(ylab = "FDis", cex.lab = 1.65, line = 3.75)
mtext(text = expression(bold("C")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 FDis.p.means - FDis.p.SEs,
			 axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 FDis.p.means + FDis.p.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## By stream
plot(c(0.1, 0.2, 0.3, 0.4), FDis.s.means, pch = 19, type = "p", ylim = c(0, 3),
		 xlim = c(0, 0.5), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2, 0.3, 0.4), lab = FALSE, tick = FALSE, 
		 cex.axis = 1.55)
mtext(text = expression(bold("D")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
						lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 FDis.s.means - FDis.s.SEs,
			 axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
			 		 lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 FDis.s.means + FDis.s.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## Plot biomass-----------------------------------------------------------#

## By pack type
plot(c(0.1, 0.2), biomass.p.means, pch = 19, type = "p", ylim = c(0, 10), 
		 xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5)
axis(2, las = 1, at = c(0, 5, 10), cex.axis = 1.45)
title(ylab = "Biomass \n(mg/g leaf litter)", cex.lab = 1.65, line = 2.75)
mtext(text = expression(bold("E")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 biomass.p.means - biomass.p.SEs,
			 axis(1, at = c(0.1, 0.2), lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 biomass.p.means + biomass.p.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## By stream
plot(c(0.1, 0.2, 0.3, 0.4), biomass.s.means, pch = 19, type = "p", ylim = c(0, 10),
		 xlim = c(0, 0.5), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2, 0.3, 0.4), lab = FALSE, tick = FALSE, 
		 cex.axis = 1.55)
mtext(text = expression(bold("F")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
						lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 biomass.s.means - biomass.s.SEs,
			 axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
			 		 lab = FALSE, tick = FALSE, cex.axis = 1.5),
			 biomass.s.means + biomass.s.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## Plot density-----------------------------------------------------------#

## By pack type
plot(c(0.1, 0.2), density.p.means, pch = 19, type = "p", ylim = c(0, 45), 
		 xlim = c(0, 0.3), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), cex.axis = 1.25)
axis(2, las = 1, at = c(0, 15, 30, 45), cex.axis = 1.275)
title(xlab = "Leaf Pack Type", ylab = "Density \n(no./g leaf litter)", 
			cex.lab = 1.65, line = 2.75)
mtext(text = expression(bold("G")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), cex.axis = 1.25),
			 density.p.means - density.p.SEs,
			 axis(1, at = c(0.1, 0.2), lab = c("LEP", "HEP"), cex.axis = 1.25),
			 density.p.means + density.p.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)

## By stream
plot(c(0.1, 0.2, 0.3, 0.4), density.s.means, pch = 19, type = "p", ylim = c(0, 45),
		 xlim = c(0, 0.5), axes = FALSE, ann = FALSE, lwd = 2, col = "gray0",
		 cex = 1.25)
axis(1, at = c(0.1, 0.2, 0.3, 0.4), lab = c("LE1", "LE2", "HE1", "HE2"), 
		 cex.axis = 1.25)
title(xlab = "Stream", cex.lab = 1.65, line = 2.75)
mtext(text = expression(bold("H")), side = 3, line = -1.75, adj = 0.05, 
			cex = 1.0)
arrows(axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
						lab = c("LE1", "LE2", "HE1", "HE2"), cex.axis = 1.25),
			 density.s.means - density.s.SEs,
			 axis(1, at = c(0.1, 0.2, 0.3, 0.4), 
			 		 lab = c("LE1", "LE2", "HE1", "HE2"), cex.axis = 1.25),
			 density.s.means + density.s.SEs,
			 length = 0.05, angle = 90, code = 3, lwd = 1.5, col = "gray0")
box(lwd = 2)


#=========================================================================#
#                               End of script                             #
#=========================================================================#